CartApi class

Constructors

CartApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCart(CartItemModel cart) Future<Either<String, void>>
deleteCart(int id) Future<Either<String, void>>
fetchCart(int id) Future<Either<String, CartItemModel>>
fetchCarts() Future<Either<String, List<CartItemModel>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateCart(CartItemModel cart) Future<Either<String, void>>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

baseUrl → const String