User class

Available extensions

Constructors

User({required int id, required String username, required String email, required String password})
const

Properties

email String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
password String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toModel() UserItemModel

Available on User, provided by the UserMapper extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited