ProductApi class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createProduct(
ProductItemModel product) → Future< Either< String, void> > -
deleteProduct(
int id) → Future< Either< String, void> > -
fetchProduct(
int id) → Future< Either< String, ProductItemModel> > -
fetchProducts(
) → Future< Either< String, List< >ProductItemModel> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProduct(
ProductItemModel product) → Future< Either< String, void> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited